@@ -1,10 +1,10 @@
-# $Id: IsTypePad.pm 1798 2005-01-28 06:40:23Z btrott $
+# $Id: IsTypePad.pm 1811 2005-03-16 22:50:01Z btrott $
 
 package WWW::Blog::Metadata::IsTypePad;
 use strict;
 
 use WWW::Blog::Metadata;
-WWW::Blog::Metadata->mk_accessors(qw( is_typepad ));
+WWW::Blog::Metadata->mk_accessors(qw( is_typepad finished ));
 
 sub on_got_html {
     my $class = shift;
@@ -13,4 +13,11 @@ sub on_got_html {
 }
 sub on_got_html_order { 99 }
 
+sub on_finished {
+    my $class = shift;
+    my($meta) = @_;
+    $meta->finished(1);
+}
+sub on_finished_order { 99 }
+
 1;
